# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/core/v1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from hyperlane.core.v1 import types_pb2 as hyperlane_dot_core_dot_v1_dot_types__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dhyperlane/core/v1/query.proto\x12\x11hyperlane.core.v1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1dhyperlane/core/v1/types.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\"_\n\x15QueryMailboxesRequest\x12\x46\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xa6\x01\n\x16QueryMailboxesResponse\x12\x43\n\tmailboxes\x18\x01 \x03(\x0b\x32\x1a.hyperlane.core.v1.MailboxB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\tmailboxes\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"%\n\x13QueryMailboxRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"W\n\x14QueryMailboxResponse\x12?\n\x07mailbox\x18\x01 \x01(\x0b\x32\x1a.hyperlane.core.v1.MailboxB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x07mailbox\"F\n\x15QueryDeliveredRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1d\n\nmessage_id\x18\x02 \x01(\tR\tmessageId\"6\n\x16QueryDeliveredResponse\x12\x1c\n\tdelivered\x18\x01 \x01(\x08R\tdelivered\"8\n\x18QueryRecipientIsmRequest\x12\x1c\n\trecipient\x18\x01 \x01(\tR\trecipient\"2\n\x19QueryRecipientIsmResponse\x12\x15\n\x06ism_id\x18\x01 \x01(\tR\x05ismId\"\x84\x01\n\x18QueryVerifyDryRunRequest\x12\x15\n\x06ism_id\x18\x01 \x01(\tR\x05ismId\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\x12\x1a\n\x08metadata\x18\x03 \x01(\tR\x08metadata\x12\x1b\n\tgas_limit\x18\x04 \x01(\tR\x08gasLimit\"7\n\x19QueryVerifyDryRunResponse\x12\x1a\n\x08verified\x18\x01 \x01(\x08R\x08verified\"\x15\n\x13QueryRegisteredISMs\"/\n\x1bQueryRegisteredISMsResponse\x12\x10\n\x03ids\x18\x01 \x03(\rR\x03ids\"\x16\n\x14QueryRegisteredHooks\"0\n\x1cQueryRegisteredHooksResponse\x12\x10\n\x03ids\x18\x01 \x03(\rR\x03ids\"\x15\n\x13QueryRegisteredApps\"/\n\x1bQueryRegisteredAppsResponse\x12\x10\n\x03ids\x18\x01 \x03(\rR\x03ids2\x97\t\n\x05Query\x12\x81\x01\n\tMailboxes\x12(.hyperlane.core.v1.QueryMailboxesRequest\x1a).hyperlane.core.v1.QueryMailboxesResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/hyperlane/v1/mailboxes\x12\x80\x01\n\x07Mailbox\x12&.hyperlane.core.v1.QueryMailboxRequest\x1a\'.hyperlane.core.v1.QueryMailboxResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/hyperlane/v1/mailboxes/{id}\x12\x9d\x01\n\tDelivered\x12(.hyperlane.core.v1.QueryDeliveredRequest\x1a).hyperlane.core.v1.QueryDeliveredResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/hyperlane/v1/mailboxes/{id}/delivered/{message_id}\x12\x9a\x01\n\x0cRecipientIsm\x12+.hyperlane.core.v1.QueryRecipientIsmRequest\x1a,.hyperlane.core.v1.QueryRecipientIsmResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/hyperlane/v1/recipient_ism/{recipient}\x12\x8f\x01\n\x0cVerifyDryRun\x12+.hyperlane.core.v1.QueryVerifyDryRunRequest\x1a,.hyperlane.core.v1.QueryVerifyDryRunResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/hyperlane/v1/verify_dry_run\x12\x8f\x01\n\x0eRegisteredISMs\x12&.hyperlane.core.v1.QueryRegisteredISMs\x1a..hyperlane.core.v1.QueryRegisteredISMsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/hyperlane/v1/registered_isms\x12\x93\x01\n\x0fRegisteredHooks\x12\'.hyperlane.core.v1.QueryRegisteredHooks\x1a/.hyperlane.core.v1.QueryRegisteredHooksResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/hyperlane/v1/registered_hooks\x12\x8f\x01\n\x0eRegisteredApps\x12&.hyperlane.core.v1.QueryRegisteredApps\x1a..hyperlane.core.v1.QueryRegisteredAppsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/hyperlane/v1/registered_appsB\xc3\x01\n\x15\x63om.hyperlane.core.v1B\nQueryProtoP\x01Z8github.com/bcp-innovations/hyperlane-cosmos/x/core/types\xa2\x02\x03HCX\xaa\x02\x11Hyperlane.Core.V1\xca\x02\x11Hyperlane\\Core\\V1\xe2\x02\x1dHyperlane\\Core\\V1\\GPBMetadata\xea\x02\x13Hyperlane::Core::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.core.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.hyperlane.core.v1B\nQueryProtoP\001Z8github.com/bcp-innovations/hyperlane-cosmos/x/core/types\242\002\003HCX\252\002\021Hyperlane.Core.V1\312\002\021Hyperlane\\Core\\V1\342\002\035Hyperlane\\Core\\V1\\GPBMetadata\352\002\023Hyperlane::Core::V1'
  _globals['_QUERYMAILBOXESRESPONSE'].fields_by_name['mailboxes']._loaded_options = None
  _globals['_QUERYMAILBOXESRESPONSE'].fields_by_name['mailboxes']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYMAILBOXRESPONSE'].fields_by_name['mailbox']._loaded_options = None
  _globals['_QUERYMAILBOXRESPONSE'].fields_by_name['mailbox']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERY'].methods_by_name['Mailboxes']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Mailboxes']._serialized_options = b'\202\323\344\223\002\031\022\027/hyperlane/v1/mailboxes'
  _globals['_QUERY'].methods_by_name['Mailbox']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Mailbox']._serialized_options = b'\202\323\344\223\002\036\022\034/hyperlane/v1/mailboxes/{id}'
  _globals['_QUERY'].methods_by_name['Delivered']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Delivered']._serialized_options = b'\202\323\344\223\0025\0223/hyperlane/v1/mailboxes/{id}/delivered/{message_id}'
  _globals['_QUERY'].methods_by_name['RecipientIsm']._loaded_options = None
  _globals['_QUERY'].methods_by_name['RecipientIsm']._serialized_options = b'\202\323\344\223\002)\022\'/hyperlane/v1/recipient_ism/{recipient}'
  _globals['_QUERY'].methods_by_name['VerifyDryRun']._loaded_options = None
  _globals['_QUERY'].methods_by_name['VerifyDryRun']._serialized_options = b'\202\323\344\223\002\036\022\034/hyperlane/v1/verify_dry_run'
  _globals['_QUERY'].methods_by_name['RegisteredISMs']._loaded_options = None
  _globals['_QUERY'].methods_by_name['RegisteredISMs']._serialized_options = b'\202\323\344\223\002\037\022\035/hyperlane/v1/registered_isms'
  _globals['_QUERY'].methods_by_name['RegisteredHooks']._loaded_options = None
  _globals['_QUERY'].methods_by_name['RegisteredHooks']._serialized_options = b'\202\323\344\223\002 \022\036/hyperlane/v1/registered_hooks'
  _globals['_QUERY'].methods_by_name['RegisteredApps']._loaded_options = None
  _globals['_QUERY'].methods_by_name['RegisteredApps']._serialized_options = b'\202\323\344\223\002\037\022\035/hyperlane/v1/registered_apps'
  _globals['_QUERYMAILBOXESREQUEST']._serialized_start=198
  _globals['_QUERYMAILBOXESREQUEST']._serialized_end=293
  _globals['_QUERYMAILBOXESRESPONSE']._serialized_start=296
  _globals['_QUERYMAILBOXESRESPONSE']._serialized_end=462
  _globals['_QUERYMAILBOXREQUEST']._serialized_start=464
  _globals['_QUERYMAILBOXREQUEST']._serialized_end=501
  _globals['_QUERYMAILBOXRESPONSE']._serialized_start=503
  _globals['_QUERYMAILBOXRESPONSE']._serialized_end=590
  _globals['_QUERYDELIVEREDREQUEST']._serialized_start=592
  _globals['_QUERYDELIVEREDREQUEST']._serialized_end=662
  _globals['_QUERYDELIVEREDRESPONSE']._serialized_start=664
  _globals['_QUERYDELIVEREDRESPONSE']._serialized_end=718
  _globals['_QUERYRECIPIENTISMREQUEST']._serialized_start=720
  _globals['_QUERYRECIPIENTISMREQUEST']._serialized_end=776
  _globals['_QUERYRECIPIENTISMRESPONSE']._serialized_start=778
  _globals['_QUERYRECIPIENTISMRESPONSE']._serialized_end=828
  _globals['_QUERYVERIFYDRYRUNREQUEST']._serialized_start=831
  _globals['_QUERYVERIFYDRYRUNREQUEST']._serialized_end=963
  _globals['_QUERYVERIFYDRYRUNRESPONSE']._serialized_start=965
  _globals['_QUERYVERIFYDRYRUNRESPONSE']._serialized_end=1020
  _globals['_QUERYREGISTEREDISMS']._serialized_start=1022
  _globals['_QUERYREGISTEREDISMS']._serialized_end=1043
  _globals['_QUERYREGISTEREDISMSRESPONSE']._serialized_start=1045
  _globals['_QUERYREGISTEREDISMSRESPONSE']._serialized_end=1092
  _globals['_QUERYREGISTEREDHOOKS']._serialized_start=1094
  _globals['_QUERYREGISTEREDHOOKS']._serialized_end=1116
  _globals['_QUERYREGISTEREDHOOKSRESPONSE']._serialized_start=1118
  _globals['_QUERYREGISTEREDHOOKSRESPONSE']._serialized_end=1166
  _globals['_QUERYREGISTEREDAPPS']._serialized_start=1168
  _globals['_QUERYREGISTEREDAPPS']._serialized_end=1189
  _globals['_QUERYREGISTEREDAPPSRESPONSE']._serialized_start=1191
  _globals['_QUERYREGISTEREDAPPSRESPONSE']._serialized_end=1238
  _globals['_QUERY']._serialized_start=1241
  _globals['_QUERY']._serialized_end=2416
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from hyperlane.core.post_dispatch.v1 import query_pb2 as hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2


class QueryStub(object):
    """Msg defines the module Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Igps = channel.unary_unary(
                '/hyperlane.core.post_dispatch.v1.Query/Igps',
                request_serializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryIgpsRequest.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryIgpsResponse.FromString,
                _registered_method=True)
        self.Igp = channel.unary_unary(
                '/hyperlane.core.post_dispatch.v1.Query/Igp',
                request_serializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryIgpRequest.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryIgpResponse.FromString,
                _registered_method=True)
        self.DestinationGasConfigs = channel.unary_unary(
                '/hyperlane.core.post_dispatch.v1.Query/DestinationGasConfigs',
                request_serializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryDestinationGasConfigsRequest.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryDestinationGasConfigsResponse.FromString,
                _registered_method=True)
        self.QuoteGasPayment = channel.unary_unary(
                '/hyperlane.core.post_dispatch.v1.Query/QuoteGasPayment',
                request_serializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryQuoteGasPaymentRequest.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryQuoteGasPaymentResponse.FromString,
                _registered_method=True)
        self.MerkleTreeHooks = channel.unary_unary(
                '/hyperlane.core.post_dispatch.v1.Query/MerkleTreeHooks',
                request_serializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryMerkleTreeHooksRequest.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryMerkleTreeHooksResponse.FromString,
                _registered_method=True)
        self.MerkleTreeHook = channel.unary_unary(
                '/hyperlane.core.post_dispatch.v1.Query/MerkleTreeHook',
                request_serializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryMerkleTreeHookRequest.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryMerkleTreeHookResponse.FromString,
                _registered_method=True)
        self.NoopHooks = channel.unary_unary(
                '/hyperlane.core.post_dispatch.v1.Query/NoopHooks',
                request_serializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryNoopHooksRequest.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryNoopHooksResponse.FromString,
                _registered_method=True)
        self.NoopHook = channel.unary_unary(
                '/hyperlane.core.post_dispatch.v1.Query/NoopHook',
                request_serializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryNoopHookRequest.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryNoopHookResponse.FromString,
                _registered_method=True)


class QueryServicer(object):
    """Msg defines the module Msg service.
    """

    def Igps(self, request, context):
        """Igps ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Igp(self, request, context):
        """Igp ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DestinationGasConfigs(self, request, context):
        """DestinationGasConfigs ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QuoteGasPayment(self, request, context):
        """QuoteGasPayment ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MerkleTreeHooks(self, request, context):
        """MerkleTreeHooks ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MerkleTreeHook(self, request, context):
        """MerkleTreeHook ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def NoopHooks(self, request, context):
        """NoopHooks ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def NoopHook(self, request, context):
        """NoopHook ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Igps': grpc.unary_unary_rpc_method_handler(
                    servicer.Igps,
                    request_deserializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryIgpsRequest.FromString,
                    response_serializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryIgpsResponse.SerializeToString,
            ),
            'Igp': grpc.unary_unary_rpc_method_handler(
                    servicer.Igp,
                    request_deserializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryIgpRequest.FromString,
                    response_serializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryIgpResponse.SerializeToString,
            ),
            'DestinationGasConfigs': grpc.unary_unary_rpc_method_handler(
                    servicer.DestinationGasConfigs,
                    request_deserializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryDestinationGasConfigsRequest.FromString,
                    response_serializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryDestinationGasConfigsResponse.SerializeToString,
            ),
            'QuoteGasPayment': grpc.unary_unary_rpc_method_handler(
                    servicer.QuoteGasPayment,
                    request_deserializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryQuoteGasPaymentRequest.FromString,
                    response_serializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryQuoteGasPaymentResponse.SerializeToString,
            ),
            'MerkleTreeHooks': grpc.unary_unary_rpc_method_handler(
                    servicer.MerkleTreeHooks,
                    request_deserializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryMerkleTreeHooksRequest.FromString,
                    response_serializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryMerkleTreeHooksResponse.SerializeToString,
            ),
            'MerkleTreeHook': grpc.unary_unary_rpc_method_handler(
                    servicer.MerkleTreeHook,
                    request_deserializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryMerkleTreeHookRequest.FromString,
                    response_serializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryMerkleTreeHookResponse.SerializeToString,
            ),
            'NoopHooks': grpc.unary_unary_rpc_method_handler(
                    servicer.NoopHooks,
                    request_deserializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryNoopHooksRequest.FromString,
                    response_serializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryNoopHooksResponse.SerializeToString,
            ),
            'NoopHook': grpc.unary_unary_rpc_method_handler(
                    servicer.NoopHook,
                    request_deserializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryNoopHookRequest.FromString,
                    response_serializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryNoopHookResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'hyperlane.core.post_dispatch.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('hyperlane.core.post_dispatch.v1.Query', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Msg defines the module Msg service.
    """

    @staticmethod
    def Igps(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.post_dispatch.v1.Query/Igps',
            hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryIgpsRequest.SerializeToString,
            hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryIgpsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Igp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.post_dispatch.v1.Query/Igp',
            hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryIgpRequest.SerializeToString,
            hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryIgpResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DestinationGasConfigs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.post_dispatch.v1.Query/DestinationGasConfigs',
            hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryDestinationGasConfigsRequest.SerializeToString,
            hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryDestinationGasConfigsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def QuoteGasPayment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.post_dispatch.v1.Query/QuoteGasPayment',
            hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryQuoteGasPaymentRequest.SerializeToString,
            hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryQuoteGasPaymentResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def MerkleTreeHooks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.post_dispatch.v1.Query/MerkleTreeHooks',
            hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryMerkleTreeHooksRequest.SerializeToString,
            hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryMerkleTreeHooksResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def MerkleTreeHook(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.post_dispatch.v1.Query/MerkleTreeHook',
            hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryMerkleTreeHookRequest.SerializeToString,
            hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryMerkleTreeHookResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def NoopHooks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.post_dispatch.v1.Query/NoopHooks',
            hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryNoopHooksRequest.SerializeToString,
            hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryNoopHooksResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def NoopHook(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.post_dispatch.v1.Query/NoopHook',
            hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryNoopHookRequest.SerializeToString,
            hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_query__pb2.QueryNoopHookResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/core/interchain_security/v1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3hyperlane/core/interchain_security/v1/genesis.proto\x12%hyperlane.core.interchain_security.v1\x1a\x19google/protobuf/any.proto\x1a\x14gogoproto/gogo.proto\"\xce\x01\n\x0cGenesisState\x12(\n\x04isms\x18\x01 \x03(\x0b\x32\x14.google.protobuf.AnyR\x04isms\x12\x93\x01\n\x1bvalidator_storage_locations\x18\x02 \x03(\x0b\x32M.hyperlane.core.interchain_security.v1.GenesisValidatorStorageLocationWrapperB\x04\xc8\xde\x1f\x00R\x19validatorStorageLocations\"\xb5\x01\n&GenesisValidatorStorageLocationWrapper\x12\x1d\n\nmailbox_id\x18\x01 \x01(\x04R\tmailboxId\x12+\n\x11validator_address\x18\x02 \x01(\tR\x10validatorAddress\x12\x14\n\x05index\x18\x03 \x01(\x04R\x05index\x12)\n\x10storage_location\x18\x04 \x01(\tR\x0fstorageLocationB\xbd\x02\n)com.hyperlane.core.interchain_security.v1B\x0cGenesisProtoP\x01ZOgithub.com/bcp-innovations/hyperlane-cosmos/x/core/01_interchain_security/types\xa2\x02\x03HCI\xaa\x02$Hyperlane.Core.InterchainSecurity.V1\xca\x02$Hyperlane\\Core\\InterchainSecurity\\V1\xe2\x02\x30Hyperlane\\Core\\InterchainSecurity\\V1\\GPBMetadata\xea\x02\'Hyperlane::Core::InterchainSecurity::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.core.interchain_security.v1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)com.hyperlane.core.interchain_security.v1B\014GenesisProtoP\001ZOgithub.com/bcp-innovations/hyperlane-cosmos/x/core/01_interchain_security/types\242\002\003HCI\252\002$Hyperlane.Core.InterchainSecurity.V1\312\002$Hyperlane\\Core\\InterchainSecurity\\V1\342\0020Hyperlane\\Core\\InterchainSecurity\\V1\\GPBMetadata\352\002\'Hyperlane::Core::InterchainSecurity::V1'
  _globals['_GENESISSTATE'].fields_by_name['validator_storage_locations']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['validator_storage_locations']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE']._serialized_start=144
  _globals['_GENESISSTATE']._serialized_end=350
  _globals['_GENESISVALIDATORSTORAGELOCATIONWRAPPER']._serialized_start=353
  _globals['_GENESISVALIDATORSTORAGELOCATIONWRAPPER']._serialized_end=534
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/warp/v1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from hyperlane.warp.v1 import types_pb2 as hyperlane_dot_warp_dot_v1_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ahyperlane/warp/v1/tx.proto\x12\x11hyperlane.warp.v1\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x14gogoproto/gogo.proto\x1a\x11\x61mino/amino.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1dhyperlane/warp/v1/types.proto\"\x94\x02\n\x18MsgCreateCollateralToken\x12.\n\x05owner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12j\n\x0eorigin_mailbox\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\roriginMailbox\x12!\n\x0corigin_denom\x18\x03 \x01(\tR\x0boriginDenom:9\x82\xe7\xb0*\x05owner\x8a\xe7\xb0**hyperlane/warp/v1/MsgCreateCollateralToken\"w\n MsgCreateCollateralTokenResponse\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\"\xef\x01\n\x17MsgCreateSyntheticToken\x12.\n\x05owner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12j\n\x0eorigin_mailbox\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\roriginMailbox:8\x82\xe7\xb0*\x05owner\x8a\xe7\xb0*)hyperlane/warp/v1/MsgCreateSyntheticToken\"\x9e\x02\n\x1dMsgCreateNativeSyntheticToken\x12.\n\x05owner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12j\n\x0eorigin_mailbox\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\roriginMailbox\x12!\n\x0corigin_denom\x18\x03 \x01(\tR\x0boriginDenom:>\x82\xe7\xb0*\x05owner\x8a\xe7\xb0*/hyperlane/warp/v1/MsgCreateNativeSyntheticToken\"v\n\x1fMsgCreateSyntheticTokenResponse\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\"\xf3\x02\n\x0bMsgSetToken\x12.\n\x05owner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12^\n\x08token_id\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x07tokenId\x12\x1b\n\tnew_owner\x18\x03 \x01(\tR\x08newOwner\x12Z\n\x06ism_id\x18\x04 \x01(\tBC\xc8\xde\x1f\x01\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05ismId\x12-\n\x12renounce_ownership\x18\x07 \x01(\x08R\x11renounceOwnership:,\x82\xe7\xb0*\x05owner\x8a\xe7\xb0*\x1dhyperlane/warp/v1/MsgSetToken\"\x15\n\x13MsgSetTokenResponse\"\xa5\x02\n\x15MsgEnrollRemoteRouter\x12.\n\x05owner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12^\n\x08token_id\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x07tokenId\x12\x44\n\rremote_router\x18\x03 \x01(\x0b\x32\x1f.hyperlane.warp.v1.RemoteRouterR\x0cremoteRouter:6\x82\xe7\xb0*\x05owner\x8a\xe7\xb0*\'hyperlane/warp/v1/MsgEnrollRemoteRouter\"\x1f\n\x1dMsgEnrollRemoteRouterResponse\"\x88\x02\n\x15MsgUnrollRemoteRouter\x12.\n\x05owner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12^\n\x08token_id\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x07tokenId\x12\'\n\x0freceiver_domain\x18\x03 \x01(\rR\x0ereceiverDomain:6\x82\xe7\xb0*\x05owner\x8a\xe7\xb0*\'hyperlane/warp/v1/MsgUnrollRemoteRouter\"\x1f\n\x1dMsgUnrollRemoteRouterResponse\"\xce\x05\n\x11MsgRemoteTransfer\x12\x30\n\x06sender\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x06sender\x12^\n\x08token_id\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x07tokenId\x12-\n\x12\x64\x65stination_domain\x18\x03 \x01(\rR\x11\x64\x65stinationDomain\x12\x61\n\trecipient\x18\x04 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\trecipient\x12H\n\x06\x61mount\x18\x05 \x01(\tB0\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xd2\xb4-\ncosmos.Int\xa8\xe7\xb0*\x01R\x06\x61mount\x12i\n\x0e\x63ustom_hook_id\x18\x06 \x01(\tBC\xc8\xde\x1f\x01\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x0c\x63ustomHookId\x12:\n\tgas_limit\x18\x07 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x08gasLimit\x12=\n\x07max_fee\x18\x08 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06maxFee\x12\x30\n\x14\x63ustom_hook_metadata\x18\t \x01(\tR\x12\x63ustomHookMetadata:3\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*#hyperlane/warp/v1/MsgRemoteTransfer\"\x7f\n\x19MsgRemoteTransferResponse\x12\x62\n\nmessage_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\tmessageId2\xa2\x06\n\x03Msg\x12y\n\x15\x43reateCollateralToken\x12+.hyperlane.warp.v1.MsgCreateCollateralToken\x1a\x33.hyperlane.warp.v1.MsgCreateCollateralTokenResponse\x12v\n\x14\x43reateSyntheticToken\x12*.hyperlane.warp.v1.MsgCreateSyntheticToken\x1a\x32.hyperlane.warp.v1.MsgCreateSyntheticTokenResponse\x12\x82\x01\n\x1a\x43reateNativeSyntheticToken\x12\x30.hyperlane.warp.v1.MsgCreateNativeSyntheticToken\x1a\x32.hyperlane.warp.v1.MsgCreateSyntheticTokenResponse\x12R\n\x08SetToken\x12\x1e.hyperlane.warp.v1.MsgSetToken\x1a&.hyperlane.warp.v1.MsgSetTokenResponse\x12p\n\x12\x45nrollRemoteRouter\x12(.hyperlane.warp.v1.MsgEnrollRemoteRouter\x1a\x30.hyperlane.warp.v1.MsgEnrollRemoteRouterResponse\x12p\n\x12UnrollRemoteRouter\x12(.hyperlane.warp.v1.MsgUnrollRemoteRouter\x1a\x30.hyperlane.warp.v1.MsgUnrollRemoteRouterResponse\x12\x64\n\x0eRemoteTransfer\x12$.hyperlane.warp.v1.MsgRemoteTransfer\x1a,.hyperlane.warp.v1.MsgRemoteTransferResponse\x1a\x05\x80\xe7\xb0*\x01\x42\xc0\x01\n\x15\x63om.hyperlane.warp.v1B\x07TxProtoP\x01Z8github.com/bcp-innovations/hyperlane-cosmos/x/warp/types\xa2\x02\x03HWX\xaa\x02\x11Hyperlane.Warp.V1\xca\x02\x11Hyperlane\\Warp\\V1\xe2\x02\x1dHyperlane\\Warp\\V1\\GPBMetadata\xea\x02\x13Hyperlane::Warp::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.warp.v1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.hyperlane.warp.v1B\007TxProtoP\001Z8github.com/bcp-innovations/hyperlane-cosmos/x/warp/types\242\002\003HWX\252\002\021Hyperlane.Warp.V1\312\002\021Hyperlane\\Warp\\V1\342\002\035Hyperlane\\Warp\\V1\\GPBMetadata\352\002\023Hyperlane::Warp::V1'
  _globals['_MSGCREATECOLLATERALTOKEN'].fields_by_name['owner']._loaded_options = None
  _globals['_MSGCREATECOLLATERALTOKEN'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCREATECOLLATERALTOKEN'].fields_by_name['origin_mailbox']._loaded_options = None
  _globals['_MSGCREATECOLLATERALTOKEN'].fields_by_name['origin_mailbox']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGCREATECOLLATERALTOKEN']._loaded_options = None
  _globals['_MSGCREATECOLLATERALTOKEN']._serialized_options = b'\202\347\260*\005owner\212\347\260**hyperlane/warp/v1/MsgCreateCollateralToken'
  _globals['_MSGCREATECOLLATERALTOKENRESPONSE'].fields_by_name['id']._loaded_options = None
  _globals['_MSGCREATECOLLATERALTOKENRESPONSE'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGCREATESYNTHETICTOKEN'].fields_by_name['owner']._loaded_options = None
  _globals['_MSGCREATESYNTHETICTOKEN'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCREATESYNTHETICTOKEN'].fields_by_name['origin_mailbox']._loaded_options = None
  _globals['_MSGCREATESYNTHETICTOKEN'].fields_by_name['origin_mailbox']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGCREATESYNTHETICTOKEN']._loaded_options = None
  _globals['_MSGCREATESYNTHETICTOKEN']._serialized_options = b'\202\347\260*\005owner\212\347\260*)hyperlane/warp/v1/MsgCreateSyntheticToken'
  _globals['_MSGCREATENATIVESYNTHETICTOKEN'].fields_by_name['owner']._loaded_options = None
  _globals['_MSGCREATENATIVESYNTHETICTOKEN'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCREATENATIVESYNTHETICTOKEN'].fields_by_name['origin_mailbox']._loaded_options = None
  _globals['_MSGCREATENATIVESYNTHETICTOKEN'].fields_by_name['origin_mailbox']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGCREATENATIVESYNTHETICTOKEN']._loaded_options = None
  _globals['_MSGCREATENATIVESYNTHETICTOKEN']._serialized_options = b'\202\347\260*\005owner\212\347\260*/hyperlane/warp/v1/MsgCreateNativeSyntheticToken'
  _globals['_MSGCREATESYNTHETICTOKENRESPONSE'].fields_by_name['id']._loaded_options = None
  _globals['_MSGCREATESYNTHETICTOKENRESPONSE'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGSETTOKEN'].fields_by_name['owner']._loaded_options = None
  _globals['_MSGSETTOKEN'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSETTOKEN'].fields_by_name['token_id']._loaded_options = None
  _globals['_MSGSETTOKEN'].fields_by_name['token_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGSETTOKEN'].fields_by_name['ism_id']._loaded_options = None
  _globals['_MSGSETTOKEN'].fields_by_name['ism_id']._serialized_options = b'\310\336\037\001\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGSETTOKEN']._loaded_options = None
  _globals['_MSGSETTOKEN']._serialized_options = b'\202\347\260*\005owner\212\347\260*\035hyperlane/warp/v1/MsgSetToken'
  _globals['_MSGENROLLREMOTEROUTER'].fields_by_name['owner']._loaded_options = None
  _globals['_MSGENROLLREMOTEROUTER'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGENROLLREMOTEROUTER'].fields_by_name['token_id']._loaded_options = None
  _globals['_MSGENROLLREMOTEROUTER'].fields_by_name['token_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGENROLLREMOTEROUTER']._loaded_options = None
  _globals['_MSGENROLLREMOTEROUTER']._serialized_options = b'\202\347\260*\005owner\212\347\260*\'hyperlane/warp/v1/MsgEnrollRemoteRouter'
  _globals['_MSGUNROLLREMOTEROUTER'].fields_by_name['owner']._loaded_options = None
  _globals['_MSGUNROLLREMOTEROUTER'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUNROLLREMOTEROUTER'].fields_by_name['token_id']._loaded_options = None
  _globals['_MSGUNROLLREMOTEROUTER'].fields_by_name['token_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGUNROLLREMOTEROUTER']._loaded_options = None
  _globals['_MSGUNROLLREMOTEROUTER']._serialized_options = b'\202\347\260*\005owner\212\347\260*\'hyperlane/warp/v1/MsgUnrollRemoteRouter'
  _globals['_MSGREMOTETRANSFER'].fields_by_name['sender']._loaded_options = None
  _globals['_MSGREMOTETRANSFER'].fields_by_name['sender']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGREMOTETRANSFER'].fields_by_name['token_id']._loaded_options = None
  _globals['_MSGREMOTETRANSFER'].fields_by_name['token_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGREMOTETRANSFER'].fields_by_name['recipient']._loaded_options = None
  _globals['_MSGREMOTETRANSFER'].fields_by_name['recipient']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGREMOTETRANSFER'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGREMOTETRANSFER'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int\322\264-\ncosmos.Int\250\347\260*\001'
  _globals['_MSGREMOTETRANSFER'].fields_by_name['custom_hook_id']._loaded_options = None
  _globals['_MSGREMOTETRANSFER'].fields_by_name['custom_hook_id']._serialized_options = b'\310\336\037\001\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGREMOTETRANSFER'].fields_by_name['gas_limit']._loaded_options = None
  _globals['_MSGREMOTETRANSFER'].fields_by_name['gas_limit']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_MSGREMOTETRANSFER'].fields_by_name['max_fee']._loaded_options = None
  _globals['_MSGREMOTETRANSFER'].fields_by_name['max_fee']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGREMOTETRANSFER']._loaded_options = None
  _globals['_MSGREMOTETRANSFER']._serialized_options = b'\202\347\260*\006sender\212\347\260*#hyperlane/warp/v1/MsgRemoteTransfer'
  _globals['_MSGREMOTETRANSFERRESPONSE'].fields_by_name['message_id']._loaded_options = None
  _globals['_MSGREMOTETRANSFERRESPONSE'].fields_by_name['message_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGCREATECOLLATERALTOKEN']._serialized_start=206
  _globals['_MSGCREATECOLLATERALTOKEN']._serialized_end=482
  _globals['_MSGCREATECOLLATERALTOKENRESPONSE']._serialized_start=484
  _globals['_MSGCREATECOLLATERALTOKENRESPONSE']._serialized_end=603
  _globals['_MSGCREATESYNTHETICTOKEN']._serialized_start=606
  _globals['_MSGCREATESYNTHETICTOKEN']._serialized_end=845
  _globals['_MSGCREATENATIVESYNTHETICTOKEN']._serialized_start=848
  _globals['_MSGCREATENATIVESYNTHETICTOKEN']._serialized_end=1134
  _globals['_MSGCREATESYNTHETICTOKENRESPONSE']._serialized_start=1136
  _globals['_MSGCREATESYNTHETICTOKENRESPONSE']._serialized_end=1254
  _globals['_MSGSETTOKEN']._serialized_start=1257
  _globals['_MSGSETTOKEN']._serialized_end=1628
  _globals['_MSGSETTOKENRESPONSE']._serialized_start=1630
  _globals['_MSGSETTOKENRESPONSE']._serialized_end=1651
  _globals['_MSGENROLLREMOTEROUTER']._serialized_start=1654
  _globals['_MSGENROLLREMOTEROUTER']._serialized_end=1947
  _globals['_MSGENROLLREMOTEROUTERRESPONSE']._serialized_start=1949
  _globals['_MSGENROLLREMOTEROUTERRESPONSE']._serialized_end=1980
  _globals['_MSGUNROLLREMOTEROUTER']._serialized_start=1983
  _globals['_MSGUNROLLREMOTEROUTER']._serialized_end=2247
  _globals['_MSGUNROLLREMOTEROUTERRESPONSE']._serialized_start=2249
  _globals['_MSGUNROLLREMOTEROUTERRESPONSE']._serialized_end=2280
  _globals['_MSGREMOTETRANSFER']._serialized_start=2283
  _globals['_MSGREMOTETRANSFER']._serialized_end=3001
  _globals['_MSGREMOTETRANSFERRESPONSE']._serialized_start=3003
  _globals['_MSGREMOTETRANSFERRESPONSE']._serialized_end=3130
  _globals['_MSG']._serialized_start=3133
  _globals['_MSG']._serialized_end=3935
# @@protoc_insertion_point(module_scope)
